from distutils.core import setup
import setuptools
setup(
  name = 'MathLibrary',         
  packages = setuptools.find_packages(),   
  version = '3.0',    
  license='MIT',      
  description = 'Math Library For Python',   
  author = 'Abdulsamet Keskin',                  
  author_email = 'erdemsametkeskin25@gmail.com',      
  url = 'https://github.com/abdulsamedkeskin/MathLibrary',   
  download_url = 'https://github.com/abdulsamedkeskin/MathLibrary/archive/V3.tar.gz',    
  keywords = ['MathLibrary'],
  classifiers=[
    'Development Status :: 3 - Alpha',      
    'Intended Audience :: Developers',      
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   
    'Programming Language :: Python :: 3',      
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)